/**
 * @file
 * Attach handlers to evaluate the strength of any password fields and to check
 * that its confirmation is correct.
 *
 * Overrides default password strength markup to use Semantic UI progress bar.
 */
(function ($) {
  Drupal.behaviors.password = {
    attach: function (context, settings) {
      var translate = settings.password;
      $('input.password-field', context).once('password', function () {
        var passwordInput = $(this);
        var innerWrapper = $(this).parent();
        var outerWrapper = $(this).parent().parent();

        // Add identifying class to password element parent.
        innerWrapper.addClass('password-parent');

        // Add the password confirmation layer.
        $('input.password-confirm', outerWrapper).parent().prepend('<div class="password-confirm">' + translate['confirmTitle'] + ' <span></span></div>').addClass('confirm-parent');
        var confirmInput = $('input.password-confirm', outerWrapper);
        var confirmResult = $('div.password-confirm', outerWrapper);
        var confirmChild = $('span', confirmResult);

        // Add the description box.
        var passwordMeter = '<div class="password-strength">';
        passwordMeter += '     <span class="password-strength-title">' + translate['strengthTitle'] + '</span>';
        passwordMeter += '     <span class="password-strength-text" aria-live="assertive"></span>';
        passwordMeter += '     <div class="ui indicating progress password-indicator">';
        passwordMeter += '       <div class="bar indicator"></div>';
        passwordMeter += '     </div>';
        passwordMeter += '   </div>';
        $(confirmInput).parent().after('<div class="password-suggestions description"></div>');
        $(innerWrapper).prepend(passwordMeter);
        var passwordDescription = $('div.password-suggestions', outerWrapper).hide();

        // Check the password strength.
        var passwordCheck = function () {

          // Evaluate the password strength.
          var result = Drupal.evaluatePasswordStrength(passwordInput.val(), settings.password);

          // Update the suggestions for how to improve the password.
          if (passwordDescription.html() != result.message) {
            passwordDescription.html(result.message);
          }

          // Only show the description box if there is a weakness in the password.
          if (result.strength == 100) {
            passwordDescription.hide();
          }
          else {
            passwordDescription.show();
          }

          // Adjust the length of the strength indicator.
          $(innerWrapper).find('.indicator').css('width', result.strength + '%');

          // Update the strength indication text.
          $(innerWrapper).find('.password-strength-text').html(result.indicatorText.toLowerCase());

          passwordCheckMatch();
        };

        // Check that password and confirmation inputs match.
        var passwordCheckMatch = function () {

          if (confirmInput.val()) {
            var success = passwordInput.val() === confirmInput.val();

            // Show the confirm result.
            confirmResult.css({ visibility: 'visible' });

            // Remove the previous styling if any exists.
            if (this.confirmClass) {
              confirmChild.removeClass(this.confirmClass);
            }

            // Fill in the success message and set the class accordingly.
            var confirmClass = success ? 'ok' : 'error';
            confirmChild.html(translate['confirm' + (success ? 'Success' : 'Failure')]).addClass(confirmClass);
            this.confirmClass = confirmClass;
          }
          else {
            confirmResult.css({ visibility: 'hidden' });
          }
        };

        // Monitor keyup and blur events.
        // Blur must be used because a mouse paste does not trigger keyup.
        passwordInput.keyup(passwordCheck).focus(passwordCheck).blur(passwordCheck);
        confirmInput.keyup(passwordCheckMatch).blur(passwordCheckMatch);
      });
    }
  };

})(jQuery);
