<?php

/**
 * @file
 * Semantic UI theme implementation for comments.
 *
 * Available variables:
 * - $author: Comment author. Can be link or plain text.
 * - $content: An array of comment items. Use render($content) to print
 *   them all,
 *   print a subset such as render($content['field_example']). Use
 *   hide($content['field_example']) to temporarily suppress the printing of a
 *   given element.
 * - $created: Formatted date and time for when the comment was created.
 *   Preprocess functions can reformat it by calling format_date() with the
 *   desired parameters on the $comment->created variable.
 * - $changed: Formatted date and time for when the comment was last changed.
 *   Preprocess functions can reformat it by calling format_date() with the
 *   desired parameters on the $comment->changed variable.
 * - $new: New comment marker.
 * - $permalink: Comment permalink.
 * - $submitted: Submission information created from $author and $created during
 *   template_preprocess_comment().
 * - $picture: Authors picture.
 * - $signature: Authors signature.
 * - $status: Comment status. Possible values are:
 *   comment-unpublished, comment-published or comment-preview.
 * - $title: Linked title.
 * - $classes: String of classes that can be used to style contextually through
 *   CSS. It can be manipulated through the variable $classes_array from
 *   preprocess functions. The default values can be one or more of
 *   the following:
 *   - comment: The current template type, i.e., "theming hook".
 *   - comment-by-anonymous: Comment by an unregistered user.
 *   - comment-by-node-author: Comment by the author of the parent node.
 *   - comment-preview: When previewing a new or edited comment.
 *   The following applies only to viewers who are registered users:
 *   - comment-unpublished: An unpublished comment visible only to
 *    administrators.
 *   - comment-by-viewer: Comment by the user currently viewing the page.
 *   - comment-new: New comment since last the visit.
 * - $title_prefix (array): An array containing additional output populated by
 *   modules, intended to be displayed in front of the main title tag that
 *   appears in the template.
 * - $title_suffix (array): An array containing additional output populated by
 *   modules, intended to be displayed after the main title tag that appears in
 *   the template.
 *
 * These two variables are provided for context:
 * - $comment: Full comment object.
 * - $node: Node object the comments are attached to.
 *
 * Other variables:
 * - $classes_array: Array of html class attribute values. It is flattened
 *   into a string within the variable $classes.
 *
 * @see template_preprocess()
 * @see template_preprocess_comment()
 * @see template_process()
 * @see theme_comment()
 *
 * @ingroup themeable
 */
?>
<?php if ($is_reply_page): ?>
  <div class="ui comments container node-forum">
  <?php endif; ?>

  <div id="comment-<?php print $comment->cid; ?>" class="<?php print $classes; ?>"<?php print $attributes; ?>>
    <div class="content">
      <div class="ui segments">
        <div class="ui grey inverted attached header block segment">
          <?php if ($title_allowed): ?>
            <?php print render($title_prefix); ?>
            <strong><?php print $title; ?></strong>
            <?php print render($title_suffix); ?>
          <?php endif; ?>
          <?php print $created; ?>
          <?php if ($new): ?>
            <a class="ui top right attached red label new"><?php print $new; ?></a>
          <?php endif; ?>
        </div>
        <div class="ui attached segment grid">
          <div class="ui attached block header four wide column">
            <div>
              <div class="ui header">
                <?php print $author; ?>
              </div>
            </div>
            <?php print render($picture); ?>
          </div>
          <?php if (!empty($content['subcomments'])): ?>
            <?php hide($content['subcomments']); ?>
          <?php endif; ?>
          <div class="ui twelve wide column">
            <div class="ui grid">
              <div class="sixteen wide column"<?php print $content_attributes; ?>>
                <?php
                // We hide the comments and links now so that we can render them later.
                hide($content['links']);
                print render($content);
                ?>

                <?php if ($signature): ?>
                  <div class="user-signature clearfix">
                    <?php print $signature; ?>
                  </div>
                <?php endif; ?>
              </div>
              <div class="row">
                <div class="ui right aligned column">
                  <?php print render($content['links']) ?>
                </div>
              </div>
            </div>
          </div>
        </div>
      </div>
    </div>
    <?php if (!empty($content['subcomments'])): ?>
      <div class="comment">
        <?php print render($content['subcomments']); ?>
      </div>
    <?php endif; ?>
  </div>

  <?php if ($is_reply_page): ?>
  </div>
<?php endif; ?>
